@@ -5,11 +5,11 @@ from rest_framework.routers import APIRootView
 from netbox.api.viewsets import NetBoxModelViewSet
 from netbox_storage.api.serializers import (
     DriveSerializer,
-    FilesystemSerializer, PartitionSerializer, LinuxVolumeSerializer
+    FilesystemSerializer, PartitionSerializer, MountedVolumeSerializer
 )
 from netbox_storage.filters import DriveFilter, FilesystemFilter, \
-    PartitionFilter, LinuxVolumeFilter
-from netbox_storage.models import Drive, Filesystem, Partition, LinuxVolume
+    PartitionFilter, MountedVolumeFilter
+from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume
 
 
 class NetboxStorageRootView(APIRootView):
@@ -57,14 +57,14 @@ class PartitionViewSet(NetBoxModelViewSet):
         return Response(serializer.data)
 
 
-class LinuxVolumeViewSet(NetBoxModelViewSet):
-    queryset = LinuxVolume.objects.all()
-    serializer_class = LinuxVolumeSerializer
-    filterset_class = LinuxVolumeFilter
+class MountedVolumeViewSet(NetBoxModelViewSet):
+    queryset = MountedVolume.objects.all()
+    serializer_class = MountedVolumeSerializer
+    filterset_class = MountedVolumeFilter
 
     @action(detail=True, methods=["get"])
-    def linuxvolume(self, request, pk=None):
-        linuxvolume = LinuxVolume.objects.filter(linuxvolume__id=pk)
-        serializer = LinuxVolumeSerializer(linuxvolume, many=True, context={"request": request})
+    def mountedvolume(self, request, pk=None):
+        mountedvolume = MountedVolume.objects.filter(mountedvolume__id=pk)
+        serializer = MountedVolumeSerializer(mountedvolume, many=True, context={"request": request})
         return Response(serializer.data)
 
