@@ -156,7 +156,7 @@ class Migration(migrations.Migration):
             },
         ),
         migrations.CreateModel(
-            name="LinuxVolume",
+            name="MountedVolume",
             fields=[
                 ("created", models.DateTimeField(auto_now_add=True, null=True)),
                 ("last_updated", models.DateTimeField(auto_now=True, null=True)),
@@ -170,7 +170,7 @@ class Migration(migrations.Migration):
                 ),
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
                 ("partition",
-                 models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="partition_linuxvolume",
+                 models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="partition_mounted_volume",
                                    to="netbox_storage.partition")),
                 ("path", models.CharField(max_length=255)),
                 ("fs",
@@ -178,6 +178,7 @@ class Migration(migrations.Migration):
                                    to='netbox_storage.filesystem')),
                 ("size", models.FloatField()),
                 ("description", models.CharField(max_length=255)),
+                ("label", models.CharField(max_length=255)),
             ],
             options={
                 "ordering": ("path", "fs", "id"),
@@ -204,7 +205,7 @@ class Migration(migrations.Migration):
                 ("linux_volume",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
                                    related_name='linux_volume_storage_configuration',
-                                   to='netbox_storage.linuxvolume')),
+                                   to='netbox_storage.mountedvolume')),
             ],
         ),
     ]
