@@ -6,7 +6,6 @@ from django.urls import reverse
 from netbox.models import NetBoxModel
 
 
-
 class Drive(NetBoxModel):
     cluster = models.ForeignKey(
         to='virtualization.Cluster',
@@ -286,11 +285,11 @@ class LogicalVolume(NetBoxModel):
         ordering = ("lv_name", "description")
 
 
-class LinuxVolume(NetBoxModel):
+class MountedVolume(NetBoxModel):
     partition = models.ForeignKey(
         Partition,
         on_delete=models.CASCADE,
-        related_name='partition_linuxvolume',
+        related_name='partition_mounted_volume',
     )
     size = models.FloatField(
         verbose_name="Size (GB)"
@@ -298,6 +297,9 @@ class LinuxVolume(NetBoxModel):
     path = models.CharField(
         max_length=255,
     )
+    label = models.CharField(
+        max_length=255,
+    )
     fs = models.ForeignKey(
         Filesystem,
         on_delete=models.CASCADE,
@@ -318,7 +320,7 @@ class LinuxVolume(NetBoxModel):
     ]
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
+        return reverse("plugins:netbox_storage:mountedvolume", kwargs={"pk": self.pk})
 
     def __str__(self):
         return f"{self.partition.device}"
@@ -334,7 +336,7 @@ class StorageConfigurationLinuxVolume(NetBoxModel):
         related_name='virtual_machine_storage_configuration',
     )
     linux_volume = models.ForeignKey(
-        LinuxVolume,
+        MountedVolume,
         on_delete=models.CASCADE,
         related_name='linux_volume_storage_configuration'
     )
@@ -352,3 +354,30 @@ class StorageConfigurationLinuxVolume(NetBoxModel):
 
     def __str__(self):
         return f"Storage Configuration of the VM {self.virtual_machine}"
+
+
+class TemplateConfigurationLinuxVolume(NetBoxModel):
+    platform = models.ForeignKey(
+        to='dcim.platform',
+        on_delete=models.CASCADE,
+        related_name='platform_template_configuration',
+    )
+    linux_volume = models.ForeignKey(
+        MountedVolume,
+        on_delete=models.CASCADE,
+        related_name='linux_volume_template_configuration'
+    )
+
+    clone_fields = [
+        "virtual_machine",
+        "platform"
+    ]
+
+    class Meta:
+        ordering = ["virtual_machine", "platform"]
+
+    # def get_absolute_url(self):
+    #     return reverse("plugins:netbox_storage:storageconfiguration", kwargs={"pk": self.pk})
+
+    def __str__(self):
+        return f"Template Configuration of the Platform {self.platform}"
