@@ -1,7 +1,7 @@
 import logging
 
 from extras.plugins import PluginTemplateExtension
-from netbox_storage.models import PhysicalVolume, LogicalVolume, LinuxVolume, StorageConfigurationLinuxVolume
+from netbox_storage.models import PhysicalVolume, LogicalVolume, MountedVolume, StorageConfigurationLinuxVolume
 
 
 class LVMModel:
@@ -51,8 +51,8 @@ class RelatedDrives(PluginTemplateExtension):
             #                 lvm_model.partition_list = partition_list
 
         logger.warning(f'{lvm_list}')
-        LinuxVolume.objects.all()
-        linux_volume_list = list(LinuxVolume.objects.all())
+        MountedVolume.objects.all()
+        linux_volume_list = list(MountedVolume.objects.all())
         logger.warning(f'linuxvolumes for {linux_volume_list}')
 
         lv = LogicalVolume.objects.all()
