@@ -1,6 +1,6 @@
 from netbox.views import generic
 
-from netbox_storage.filters import PartitionFilter, PhysicalVolumeFilter
+from netbox_storage.filters import PartitionFilter
 from netbox_storage.forms import (
     PartitionImportForm,
     PartitionFilterForm,
@@ -8,9 +8,8 @@ from netbox_storage.forms import (
     PartitionBulkEditForm
 )
 
-from netbox_storage.models import Partition, PhysicalVolume
-from netbox_storage.tables import PartitionTable, PhysicalVolumeTable
-from utilities.views import register_model_view, ViewTab
+from netbox_storage.models import Partition
+from netbox_storage.tables import PartitionTable
 
 
 class PartitionListView(generic.ObjectListView):
@@ -56,24 +55,3 @@ class PartitionBulkEditView(generic.BulkEditView):
 class PartitionBulkDeleteView(generic.BulkDeleteView):
     queryset = Partition.objects.all()
     table = PartitionTable
-
-
-@register_model_view(Partition, "physicalvolumes")
-class PartitionPhysicalVolumeListView(generic.ObjectChildrenView):
-    queryset = Partition.objects.all()
-    child_model = PhysicalVolume
-    table = PhysicalVolumeTable
-    filterset = PhysicalVolumeFilter
-    template_name = "netbox_storage/partition/physicalvolume.html"
-    hide_if_empty = True
-
-    tab = ViewTab(
-        label="Physical Volumes",
-        badge=lambda obj: obj.physicalvolumes_count(),
-        hide_if_empty=True,
-    )
-
-    def get_children(self, request, parent):
-        return PhysicalVolume.objects.filter(
-            partition=parent
-        )
